@@ -33,7 +33,7 @@ class EntryListModel : public QAbstractTableModel
   Q_OBJECT
 
   public:
-                  EntryListModel( const EntryList &list );
+    explicit      EntryListModel( const EntryList &list );
 
     int           columnCount( const QModelIndex &parent = QModelIndex() ) const Q_DECL_OVERRIDE;
     QVariant      data( const QModelIndex &index, int role = Qt::DisplayRole ) const Q_DECL_OVERRIDE;
